SynthUSBII - Heros Devices 0.6.1 documentation

Skip to content
Back to top
View this page

# SynthUSBII

From: Windfreak Technologies, LLC

Class: `herosdevices.hardware.windfreak.SynthUSBII`

Driver Quality Index: stable

Windfreak SynthUSB2 RF generator driver.

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.windfreak.SynthUSBII` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
address | <class ‘str’> |  |
timeout | <class ‘float’> | 1.0 |

This JSON string can be used to start a HERO device representation of `SynthUSBII` using BOSS.

    {
        "_id": "my_SynthUSBII",
        "classname": "herosdevices.hardware.windfreak.SynthUSBII",
        "arguments": {
            "address": "<class 'str'>",
            "timeout": 1.0
        }
    }